@@ -15,10 +15,10 @@ log = logging.getLogger(__name__)
 from astkit import ast
 from astkit.render import SourceCodeRenderer
 
-major = sys.version[0]
-if major == '2':
+major = sys.version_info.major
+if major == 2:
     from astkit.compat.py2 import exec_f
-elif major == '3':
+elif major == 3:
     from astkit.compat.py3 import exec_f
 else:
     raise RuntimeError("Couldn't find a compatible 'exec_f' for version %r",
@@ -63,7 +63,7 @@ class _ModuleLoader(object):
 class _NullLoader(object):
     
     def load_module(self, fullname):
-        return sys,modules[fullname]
+        return sys.modules[fullname]
 
 class _ImportHook(object):
     """ An implementation of an import hook per PEP 302
@@ -95,7 +95,7 @@ class _ImportHook(object):
         
         package_path = os.path.join(directory, fullname.split('.')[-1], '__init__.py')
         if os.path.exists(package_path):
-            loader = ModuleLoader(package_path)
+            loader = _ModuleLoader(package_path)
             return loader
 
 class _ProcessorManager(object):
